Changelog
============


2.8 (2018-04-05)
----------------

- Add a fake request so code called that expects a request will still work [dmarks]
- Allow python scripts and other TTW code to be called from collective.cron [djay]


2.7 (2013-02-18)
----------------

- Fix various github bugs (typos, install setup, dependencies) [kiorky, gforcada, khink]


2.6 (2012-11-11)
----------------

- fix #1 & #2 [kiorky]


2.5 (2012-10-28)
----------------

- optimize API to get job status infos [kiorky]
- make better robust code [kiorky]


2.4 (2012-10-14)
----------------
- Add a log limit property to logs to limit memory & other resources usage [kiorky]
- Performance tweaks [kiorky]


2.3 (2012-10-11)
----------------
- better registry handling [kiorky]
- better jobrunner [kiorky]
- better tests  [kiorky]
- make install and restart code more robust, again [kiorky]

2.2 (2012-10-11)
----------------

- make install and restart code more robust.
  This is **release codename Wine**. A really thanks to Andreas Jung which helped me to find a difficult bug
  with ZODB transactions. (call transaction.savepoint to make _p_jar which was None to appear).
  [kiorky]


2.1 (2012-10-10)
----------------

- better tests for addons consumers [kiorky]


2.0 (2012-10-10)
----------------
- Rewrite collective.cron for better robustness, documentation & no extra dependencies on content types
  [kiorky]



1.0 (2011)
----------------
- First release

